Learn R Programming

BayesianMediationA (version 1.0.1)

summary.bma.bx.cy: Summary function for the bma.bx.cy object

Description

Calculate the Bayesian estimates, standard deviations and credible sets for the mediation effects.

Usage

# S3 method for bma.bx.cy
summary(object, ..., plot = TRUE, RE = TRUE,
quant = c(0.025, 0.25, 0.5, 0.75, 0.975), digit = 4, method = 3)

Value

This function returns an object that has the following items:

result1

The result of (in)direct estimates from method 1.

result1.re

The result of relative (in)direct estimates from method 1.

result2

The result of (in)direct estimates from method 2.

result2.re

The result of relative (in)direct estimates from method 2.

result3

The result of (in)direct estimates from method 3.

result3.re

The result of relative (in)direct estimates from method 3.

result4

The result of (in)direct estimates from method 4.

result4.re

The result of relative (in)direct estimates from method 4.

Arguments

object

The bma.bx.cy object which is the outcome of the function bam.bx.cy.

...

arguments to be passed to methods.

plot

If plot is True (default), plot the estimated (relative) effects with the predicted credit sets, using method specified by method.

RE

If RE is true, the relative effect plot is drawn.

quant

The quantiles of the estimates to be reported. By default, the quantiles are c(0.025, 0.25, 0.5, 0.75, 0.975).

digit

The number of digit to print in the result.

method

The method is printing to be used for estimation.

Author

Qingzhao Yu and Ari Li.

Examples

Run this code
# See examples at bma.bx.cy.

Run the code above in your browser using DataLab