Calculate the Bayesian estimates, standard deviations and credible sets for the mediation effects.
# S3 method for bma.bx.cy
summary(object, ..., plot = TRUE, RE = TRUE,
quant = c(0.025, 0.25, 0.5, 0.75, 0.975), digit = 4, method = 3)This function returns an object that has the following items:
The result of (in)direct estimates from method 1.
The result of relative (in)direct estimates from method 1.
The result of (in)direct estimates from method 2.
The result of relative (in)direct estimates from method 2.
The result of (in)direct estimates from method 3.
The result of relative (in)direct estimates from method 3.
The result of (in)direct estimates from method 4.
The result of relative (in)direct estimates from method 4.
The bma.bx.cy object which is the outcome of the function bam.bx.cy.
arguments to be passed to methods.
If plot is True (default), plot the estimated (relative) effects with the predicted credit sets, using method specified by method.
If RE is true, the relative effect plot is drawn.
The quantiles of the estimates to be reported. By default, the quantiles are c(0.025, 0.25, 0.5, 0.75, 0.975).
The number of digit to print in the result.
The method is printing to be used for estimation.
Qingzhao Yu and Ari Li.